@@ -4,7 +4,7 @@
  *
  *  Copyright (C) 2000-2001  Qualcomm Incorporated
  *  Copyright (C) 2002-2003  Maxim Krasnyansky <maxk@qualcomm.com>
- *  Copyright (C) 2002-2009  Marcel Holtmann <marcel@holtmann.org>
+ *  Copyright (C) 2002-2010  Marcel Holtmann <marcel@holtmann.org>
  *
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -23,8 +23,8 @@
  *
  */
 
-/* When all services should trust a remote device */
-#define GLOBAL_TRUST "[all]"
+#include <bluetooth/hci.h>
+#include <bluetooth/hci_lib.h>
 
 /*
  * Scanning modes, used by DEV_SET_MODE
@@ -39,14 +39,8 @@
 #define MODE_OFF		0x00
 #define MODE_CONNECTABLE	0x01
 #define MODE_DISCOVERABLE	0x02
-#define MODE_LIMITED		0x03
 #define MODE_UNKNOWN		0xff
 
-#define HCID_DEFAULT_DISCOVERABLE_TIMEOUT 180 /* 3 minutes */
-
-/* Timeout for hci_send_req (milliseconds) */
-#define HCI_REQ_TIMEOUT		5000
-
 struct main_opts {
 	char		host_name[40];
 	unsigned long	flags;
@@ -60,6 +54,8 @@ struct main_opts {
 	gboolean	remember_powered;
 	gboolean	reverse_sdp;
 	gboolean	name_resolv;
+	gboolean	debug_keys;
+	gboolean	attrib_server;
 
 	uint8_t		scan;
 	uint8_t		mode;
@@ -78,17 +74,12 @@ enum {
 
 extern struct main_opts main_opts;
 
-char *expand_name(char *dst, int size, char *str, int dev_id);
+void btd_start_exit_timer(void);
+void btd_stop_exit_timer(void);
 
-void hci_req_queue_remove(int dev_id, bdaddr_t *dba);
-
-void start_security_manager(int hdev);
-void stop_security_manager(int hdev);
-
-void set_pin_length(bdaddr_t *sba, int length);
-
-gboolean plugin_init(GKeyFile *config);
+gboolean plugin_init(GKeyFile *config, const char *enable,
+							const char *disable);
 void plugin_cleanup(void);
 
-void __probe_servers(const char *adapter);
-void __remove_servers(const char *adapter);
+void rfkill_init(void);
+void rfkill_exit(void);
